@@ -1,14 +1,14 @@
-from typing import Any, Collection, Dict, Union
+from typing import Any, Collection, Mapping, Union
 
 import pandas as pd
 
-from rics.performance._multi_case_timer import CandFunc, MultiCaseTimer
-from rics.performance._util import plot_run, to_dataframe
+from ._multi_case_timer import CandFunc, MultiCaseTimer
+from ._util import plot_run, to_dataframe
 
 
 def run_multivariate_test(
-    candidate_method: Union[CandFunc, Collection[CandFunc], Dict[str, CandFunc]],
-    test_data: Union[Any, Dict[str, Any]],
+    candidate_method: Union[CandFunc, Collection[CandFunc], Mapping[str, CandFunc]],
+    test_data: Union[Any, Mapping[str, Any]],
     time_per_candidate: float = 6.0,
     plot: bool = True,
     **figure_kwargs: Any,
